.. Kajiki documentation master file, created by
   sphinx-quickstart on Wed Jul  7 22:31:03 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: media/Logo.png

Welcome to Kajiki's documentation!
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. include:: ../README.rst

Documentation contents
~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2

   templating-basics.rst
   xml-templates.rst
   text-templates.rst
   migrating_from_genshi.rst
   i18n.rst
   runtime.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
